# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HostStaticNetworkConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'network_yaml': 'str',
        'mac_interface_map': 'MacInterfaceMap'
    }

    attribute_map = {
        'network_yaml': 'network_yaml',
        'mac_interface_map': 'mac_interface_map'
    }

    def __init__(self, network_yaml=None, mac_interface_map=None):  # noqa: E501
        """HostStaticNetworkConfig - a model defined in Swagger"""  # noqa: E501

        self._network_yaml = None
        self._mac_interface_map = None
        self.discriminator = None

        if network_yaml is not None:
            self.network_yaml = network_yaml
        if mac_interface_map is not None:
            self.mac_interface_map = mac_interface_map

    @property
    def network_yaml(self):
        """Gets the network_yaml of this HostStaticNetworkConfig.  # noqa: E501

        yaml string that can be processed by nmstate  # noqa: E501

        :return: The network_yaml of this HostStaticNetworkConfig.  # noqa: E501
        :rtype: str
        """
        return self._network_yaml

    @network_yaml.setter
    def network_yaml(self, network_yaml):
        """Sets the network_yaml of this HostStaticNetworkConfig.

        yaml string that can be processed by nmstate  # noqa: E501

        :param network_yaml: The network_yaml of this HostStaticNetworkConfig.  # noqa: E501
        :type: str
        """

        self._network_yaml = network_yaml

    @property
    def mac_interface_map(self):
        """Gets the mac_interface_map of this HostStaticNetworkConfig.  # noqa: E501

        mapping of host macs to logical interfaces used in the network yaml  # noqa: E501

        :return: The mac_interface_map of this HostStaticNetworkConfig.  # noqa: E501
        :rtype: MacInterfaceMap
        """
        return self._mac_interface_map

    @mac_interface_map.setter
    def mac_interface_map(self, mac_interface_map):
        """Sets the mac_interface_map of this HostStaticNetworkConfig.

        mapping of host macs to logical interfaces used in the network yaml  # noqa: E501

        :param mac_interface_map: The mac_interface_map of this HostStaticNetworkConfig.  # noqa: E501
        :type: MacInterfaceMap
        """

        self._mac_interface_map = mac_interface_map

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HostStaticNetworkConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HostStaticNetworkConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
